==> ojs-3.3.0-7.tar.gz: ojs-3.3.0-7/docs/manual/fr/settings/distribution-settings.md <==
# Paramètres de la distribution

1. [Licence](distribution-settings#license)
1. [Indexation par les moteurs de recherche](distribution-settings#indexing)
1. [Paiements](distribution-settings#payments)
1. [Accès](distribution-settings#access)
1. [Archivage](distribution-settings#archiving)

Dans les paramètres de la distribution, vous pouvez configurer comment les utilisateurs et utilisatrices découvrent, repèrent, utilisent et lisent le contenu de votre revue. Pour plus d'informations, veuillez consulter [Learning OJS 3: Distribution Settings](https://docs.pkp.sfu.ca/learning-ojs/en/settings-distribution) (en anglais).

## <a name="license"></a>Licence
Dans cet onglet, vous pouvez configurer le droit d'auteur et les droits d'utilisation au niveau de la revue. Vous pouvez également paramétrer ces droits au niveau de l'article lorsque vous publiez un article ou un numéro. 

Le **titulaire du droit d'auteur** identifie l'auteur-e ou propriétaire du droit d'auteur pour une publication, par exemple Copyright (c) 2016 par Jane Smith.

La **licence** détermine les droits d'utilisation d'une publication. Par exemple, CC-By 4.0 autorise à reproduire, redistribuer et adapter le document pour tout usage, même à des fins commerciales, en autant qu'il y ait attribution au titulaire du droit d'auteur.

## <a name="indexing"></a>Indexation par les moteurs de recherche
L'information saisie dans cet onglet optimise la découverte de votre contenu par les moteurs de recherche et les répertoires.

## <a name="payments"></a>Paiements
Si vous gérez des abonnements ou des frais de traitement des articles, vous pouvez activer les paiements dans cet onglet et sélectionner une méthode de paiement et une devise.

## <a name="access"></a>Accès
Si votre revue est en accès libre, vous pouvez conserver les paramètres par défaut. Si vous utilisez des abonnements ou que votre contenu est publié en tout ou en partie sur un site distinct d'OJS, vous pouvez modifier ces paramètres.

Nous vous encourageons à conserver l'accès OAI activé, à moins que vous n'utilisiez pas OJS pour publier votre contenu, ou que vous ne vouliez pas que vos métadonnées puissent être découvertes par protocole OAI.

## <a name="archiving"></a>Archivage
Si vous avez une entente d'archivage avec un réseau LOCKSS, vous pouvez l'activer ici afin de rendre le contenu de votre revue disponible au réseau.

==> ojs-3.3.0-22.tar.gz: ojs-3.3.0-22/docs/manual/fr/settings/distribution-settings.md <==
# Paramètres de la distribution

1. [Licence](distribution-settings#license)
1. [Indexation par les moteurs de recherche](distribution-settings#indexing)
1. [Paiements](distribution-settings#payments)
1. [Accès](distribution-settings#access)
1. [Archivage](distribution-settings#archiving)

Dans les paramètres de la distribution, vous pouvez configurer comment les utilisateurs et utilisatrices découvrent, repèrent, utilisent et lisent le contenu de votre revue. Pour plus d'informations, veuillez consulter [Apprendre OJS 3: Paramètres de distribution](https://docs.pkp.sfu.ca/learning-ojs/fr/settings-distribution).

## <a name="license"></a>Licence
Dans cet onglet, vous pouvez configurer le droit d'auteur et les droits d'utilisation au niveau de la revue. Vous pouvez également paramétrer ces droits au niveau de l'article lorsque vous publiez un article ou un numéro. 

Le **titulaire du droit d'auteur** identifie l'auteur-e ou propriétaire du droit d'auteur pour une publication, par exemple Copyright (c) 2016 par Jane Smith.

La **licence** détermine les droits d'utilisation d'une publication. Par exemple, CC-By 4.0 autorise à reproduire, redistribuer et adapter le document pour tout usage, même à des fins commerciales, en autant qu'il y ait attribution au titulaire du droit d'auteur.

## <a name="indexing"></a>Indexation par les moteurs de recherche
L'information saisie dans cet onglet optimise la découverte de votre contenu par les moteurs de recherche et les répertoires.

## <a name="payments"></a>Paiements
Si vous gérez des abonnements ou des frais de traitement des articles, vous pouvez activer les paiements dans cet onglet et sélectionner une méthode de paiement et une devise.

## <a name="access"></a>Accès
Si votre revue est en accès libre, vous pouvez conserver les paramètres par défaut. Si vous utilisez des abonnements ou que votre contenu est publié en tout ou en partie sur un site distinct d'OJS, vous pouvez modifier ces paramètres.

Nous vous encourageons à conserver l'accès OAI activé, à moins que vous n'utilisiez pas OJS pour publier votre contenu, ou que vous ne vouliez pas que vos métadonnées puissent être découvertes par protocole OAI.

## <a name="archiving"></a>Archivage
Si vous avez une entente d'archivage avec un réseau LOCKSS, vous pouvez l'activer ici afin de rendre le contenu de votre revue disponible au réseau.
